Class: TestMap::CachedSkip
- Inherits:
-
Minitest::Skip
- Object
- Minitest::Skip
- TestMap::CachedSkip
- Defined in:
- lib/test_map/plugins/minitest.rb
Overview
CachedSkip is raised to skip tests whose files haven’t changed. Subclasses Minitest::Skip so Minitest treats it as a skip, but the custom reporter can distinguish it and show C instead of S.
Instance Method Summary collapse
-
#initialize(msg = 'test-map: cached') ⇒ CachedSkip
constructor
A new instance of CachedSkip.
- #result_label ⇒ Object
Constructor Details
#initialize(msg = 'test-map: cached') ⇒ CachedSkip
Returns a new instance of CachedSkip.
8 9 10 |
# File 'lib/test_map/plugins/minitest.rb', line 8 def initialize(msg = 'test-map: cached') super end |
Instance Method Details
#result_label ⇒ Object
12 13 14 |
# File 'lib/test_map/plugins/minitest.rb', line 12 def result_label 'Cached' end |